==> haskell-deferred-folds-0.9.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deferred-folds
version: 0.9.1
id: deferred-folds-0.9.1-Fi60vYFouXJC09uJXDJJ
key: deferred-folds-0.9.1-Fi60vYFouXJC09uJXDJJ
license: MIT
copyright: (c) 2018, Metrix.AI
maintainer: Metrix.AI Tech Team <tech@metrix.ai>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
stability: Experimental
homepage: https://github.com/metrix-ai/deferred-folds
synopsis: Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.
category: Folding
abi: 031093eb0945ea00b0b70788791e3637
exposed: True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr
hidden-modules: DeferredFolds.Types DeferredFolds.UnfoldrM
                DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
                DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
                DeferredFolds.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/deferred-folds-0.9.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/deferred-folds-0.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/deferred-folds-0.9.1
hs-libraries: HSdeferred-folds-0.9.1-Fi60vYFouXJC09uJXDJJ
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    foldl-1.4.4-EXolrf5lynaAVCKfemNJIv
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             foldl-1.4.4-EXolrf5lynaAVCKfemNJIv=fde33d229ca6d62e16cb9db17a779041
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock
haddock-html: /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deferred-folds-0.9.7-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deferred-folds
version: 0.9.7
id: deferred-folds-0.9.7-JEYh2TUAKog2QrmIcKPi49
key: deferred-folds-0.9.7-JEYh2TUAKog2QrmIcKPi49
license: MIT
copyright: (c) 2018, Metrix.AI
maintainer: Metrix.AI Tech Team <tech@metrix.ai>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
stability: Experimental
homepage: https://github.com/metrix-ai/deferred-folds
synopsis: Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.
category: Folding
abi: 53d4ad36a60a84922ea97f6ececf29b1
exposed: True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr
hidden-modules: DeferredFolds.Types DeferredFolds.UnfoldrM
                DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
                DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
                DeferredFolds.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/deferred-folds-0.9.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/deferred-folds-0.9.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/deferred-folds-0.9.7
hs-libraries: HSdeferred-folds-0.9.7-JEYh2TUAKog2QrmIcKPi49
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    foldl-1.4.4-EXolrf5lynaAVCKfemNJIv
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc transformers-0.5.5.0
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             foldl-1.4.4-EXolrf5lynaAVCKfemNJIv=fde33d229ca6d62e16cb9db17a779041
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock
haddock-html: /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
